pub struct Streaming12ReleaseGate;Expand description
Mandatory SpatialRust 1.2 bounded-streaming release policy.
Implementations
Sourceimpl Streaming12ReleaseGate
impl Streaming12ReleaseGate
Sourcepub const fn required_conformance_cases() -> &'static [&'static str]
pub const fn required_conformance_cases() -> &'static [&'static str]
Returns conformance ids that must be present exactly once with Pass.
Sourcepub const fn required_receipts() -> &'static [&'static str]
pub const fn required_receipts() -> &'static [&'static str]
Returns implementation receipt ids required by the candidate.
Sourcepub const fn required_examples() -> &'static [&'static str]
pub const fn required_examples() -> &'static [&'static str]
Returns runnable workflow ids required by the candidate.
Sourcepub fn evaluate(evidence: &Streaming12ReleaseEvidence) -> ReleaseGateDecision
pub fn evaluate(evidence: &Streaming12ReleaseEvidence) -> ReleaseGateDecision
Evaluates every mandatory item and returns all denial reasons.
Sourcepub fn render_markdown(evidence: &Streaming12ReleaseEvidence) -> String
pub fn render_markdown(evidence: &Streaming12ReleaseEvidence) -> String
Generates the auditable Markdown release receipt.