pub struct Vision1ReleaseGate;Expand description
Mandatory SpatialRust Vision 1.0 release policy.
Implementations
Sourceimpl Vision1ReleaseGate
impl Vision1ReleaseGate
Sourcepub const fn required_conformance_cases() -> &'static [&'static str]
pub const fn required_conformance_cases() -> &'static [&'static str]
Returns conformance ids that must be present with Pass status.
Sourcepub const fn required_comparison_suites() -> &'static [&'static str]
pub const fn required_comparison_suites() -> &'static [&'static str]
Returns OpenCV comparison suite ids required by the release receipt.
Sourcepub const fn required_examples() -> &'static [&'static str]
pub const fn required_examples() -> &'static [&'static str]
Returns examples that must compile and run for the release candidate.
Sourcepub fn evaluate(evidence: &Vision1ReleaseEvidence) -> ReleaseGateDecision
pub fn evaluate(evidence: &Vision1ReleaseEvidence) -> ReleaseGateDecision
Evaluates all mandatory evidence and returns every denial reason.