pub struct Vision2ReleaseGate;Expand description
Mandatory SpatialRust Vision 2 release policy.
Implementations
Sourceimpl Vision2ReleaseGate
impl Vision2ReleaseGate
Sourcepub const fn required_conformance_cases() -> &'static [&'static str]
pub const fn required_conformance_cases() -> &'static [&'static str]
Returns conformance ids that must be present exactly once with Pass.
Sourcepub const fn required_receipts() -> &'static [&'static str]
pub const fn required_receipts() -> &'static [&'static str]
Returns dated receipt ids required by the release candidate.
Sourcepub const fn required_examples() -> &'static [&'static str]
pub const fn required_examples() -> &'static [&'static str]
Returns runnable examples required by the release candidate.
Sourcepub fn evaluate(evidence: &Vision2ReleaseEvidence) -> ReleaseGateDecision
pub fn evaluate(evidence: &Vision2ReleaseEvidence) -> ReleaseGateDecision
Evaluates every mandatory item and returns all denial reasons.
Sourcepub fn render_markdown(evidence: &Vision2ReleaseEvidence) -> String
pub fn render_markdown(evidence: &Vision2ReleaseEvidence) -> String
Generates the auditable Markdown receipt embedded in release docs.